magneticalc.Wire_Presets.Wire_Presets

# ``magneticalc`.`Wire_Presets`.`Wire_Presets``

class documentation

`class Wire_Presets:`

View In Hierarchy

Wire_Presets class.

Static Method | `get_by_id` | Selects a preset by name.
Static Method | `get_phase_jumping_toroidal_loop` | Generates a (phase-jumping) toroidal loop.
Class Variable | `CompensatedDoubleSquareLoop_Centered` | Undocumented
Class Variable | `CompensatedDoubleSquareLoop_Offset` | Undocumented
Class Variable | `CompensatedSolenoidCircularLoops4` | Undocumented
Class Variable | `CompensatedSolenoidCircularLoops8` | Undocumented
Class Variable | `List` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop16` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop32HiRes` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop32HiResFlat` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop32LoRes` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop32LoResFlat` | Undocumented
Class Variable | `PhaseJumpingToroidalLoop8` | Undocumented
Class Variable | `SingleCircularLoop_Offset` | Undocumented
Class Variable | `SingleSquareLoop_Centered` | Undocumented
Class Variable | `SingleSquareLoop_Offset` | Undocumented
Class Variable | `SolenoidCircularLoops4` | Undocumented
Class Variable | `SolenoidCircularLoops8` | Undocumented
Class Variable | `StraightLine` | Undocumented
Class Variable | `ToroidalLoop16` | Undocumented
Class Variable | `ToroidalLoop32HiRes` | Undocumented
Class Variable | `ToroidalLoop32HiResFlat` | Undocumented
Class Variable | `ToroidalLoop32LoRes` | Undocumented
Class Variable | `ToroidalLoop32LoResFlat` | Undocumented
Class Variable | `ToroidalLoop8` | Undocumented

@staticmethod
def get_by_id(_id_: `str`) -> `dict`:

Selects a preset by name.

Parameters
_id_: `str` | Preset ID

Returns
`dict` | Preset parameters

@staticmethod
def get_phase_jumping_toroidal_loop(n_points: `int`, n_phase_jumps: `int`, toroidal_radius: `float`, poloidal_radius: `float`, toroidal_freq: `float`, poloidal_freq: `float`, flat: `bool` = True) -> `np.ndarray`:

Generates a (phase-jumping) toroidal loop.

Parameters
n_points: `int` | Number of points
n_phase_jumps: `int` | Number of phase jumps
toroidal_radius: `float` | Toroidal radius
poloidal_radius: `float` | Poloidal radius
toroidal_freq: `float` | Toroidal frequency
poloidal_freq: `float` | Poloidal frequency
flat: `bool` | Flat mode

Returns
`np.ndarray` | Undocumented

CompensatedDoubleSquareLoop_Centered =

Undocumented

CompensatedDoubleSquareLoop_Offset =

Undocumented

CompensatedSolenoidCircularLoops4 =

Undocumented

CompensatedSolenoidCircularLoops8 =

Undocumented

List =

Undocumented

PhaseJumpingToroidalLoop16 =

Undocumented

PhaseJumpingToroidalLoop32HiRes =

Undocumented

PhaseJumpingToroidalLoop32HiResFlat =

Undocumented

PhaseJumpingToroidalLoop32LoRes =

Undocumented

PhaseJumpingToroidalLoop32LoResFlat =

Undocumented

PhaseJumpingToroidalLoop8 =

Undocumented

SingleCircularLoop_Offset =

Undocumented

SingleSquareLoop_Centered =

Undocumented

SingleSquareLoop_Offset =

Undocumented

SolenoidCircularLoops4 =

Undocumented

SolenoidCircularLoops8 =

Undocumented

StraightLine =

Undocumented

ToroidalLoop16 =

Undocumented

ToroidalLoop32HiRes =

Undocumented

ToroidalLoop32HiResFlat =

Undocumented

ToroidalLoop32LoRes =

Undocumented

ToroidalLoop32LoResFlat =

Undocumented

ToroidalLoop8 =

Undocumented